pub enum InitUserCryptoMethod {
MasterPasswordUnlock {
password: String,
master_password_unlock: MasterPasswordUnlockData,
},
ClientManagedState {},
DecryptedKey {
decrypted_user_key: String,
},
Pin {
pin: String,
pin_protected_user_key: EncString,
},
PinEnvelope {
pin: String,
pin_protected_user_key_envelope: PasswordProtectedKeyEnvelope,
},
AuthRequest {
request_private_key: B64,
method: AuthRequestMethod,
},
DeviceKey {
device_key: String,
protected_device_private_key: EncString,
device_protected_user_key: UnsignedSharedKey,
},
KeyConnector {
master_key: B64,
user_key: EncString,
},
KeyConnectorUrl {
url: String,
key_connector_key_wrapped_user_key: EncString,
},
}Expand description
The crypto method used to initialize the user cryptographic state.
Variants
MasterPasswordUnlock
Master Password Unlock
Fields
master_password_unlock: MasterPasswordUnlockDataContains the data needed to unlock with the master password
ClientManagedState
Read the user-key directly from client-managed state
Note: In contrast to InitUserCryptoMethod::DecryptedKey, this does not update the state
after initalizing
DecryptedKey
Never lock and/or biometric unlock
Fields
Pin
PIN
Fields
pin_protected_user_key: EncStringThe user’s symmetric crypto key, encrypted with the PIN. Use derive_pin_key to obtain
this.
PinEnvelope
PIN Envelope
Fields
pin_protected_user_key_envelope: PasswordProtectedKeyEnvelopeThe user’s symmetric crypto key, encrypted with the PIN-protected key envelope.
AuthRequest
Auth request
Fields
request_private_key: B64Private Key generated by the crate::auth::new_auth_request.
method: AuthRequestMethodThe type of auth request
DeviceKey
Device Key
Fields
protected_device_private_key: EncStringThe Device Private Key
device_protected_user_key: UnsignedSharedKeyThe user’s symmetric crypto key, encrypted with the Device Key.
KeyConnector
Key connector
Fields
master_key: B64Base64 encoded master key, retrieved from the key connector.
user_key: EncStringThe user’s encrypted symmetric crypto key
KeyConnectorUrl
In contrast to key-connector, this does all of the connection with key-connector in the sdk