pub struct ReinitUserCryptoRequest {
pub account_cryptographic_state: WrappedAccountCryptographicState,
pub upgrade_token: V2UpgradeToken,
}Expand description
State used to re-initialize an unlocked user’s cryptographic state after
accountCryptographicState and V2UpgradeToken are received in a sync.
This presumes the SDK is already unlocked (has user key in memory).
Fields
account_cryptographic_state: WrappedAccountCryptographicStateThe user’s account cryptographic state, encrypted under the user key
upgrade_token: V2UpgradeTokenThe SDK uses the in-store (V1) user key to extract the V2 user key from the token,
then sets the V2 user key as the active user key before decrypting
account_cryptographic_state.